from rest_framework import permissions

from core.models import Student, Reviewer, Tutor


class IsUserGenericPermission(permissions.BasePermission):
    """ Generic class that encapsulates how to identify someone
    as a member of a user Group """

    def has_permission(self, request, view):
        """ required by BasePermission. Check if user is instance of model"""
        assert self.model is not None, (
            "'%s' has to include a `model` attribute"
            % self.__class__.__name__
        )

        user = request.user
        return user.is_authenticated() and isinstance(
            user.get_associated_user(), self.model
        )


class IsStudent(IsUserGenericPermission):
    """ Has student permissions """
    model = Student


class IsReviewer(IsUserGenericPermission):
    """ Has reviewer permissions """
    model = Reviewer


class IsTutor(IsUserGenericPermission):
    """ Has tutor permissions """
    model = Tutor
