from rest_framework.test import APITestCase, APIRequestFactory, force_authenticate
from rest_framework import status
from core.models import Reviewer, SubmissionType
from core.tests import data_factories
from django.urls import reverse
from core.views import StudentApiView


class StudentPageTests(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.factory = APIRequestFactory()

    def setUp(self):
        self.submission, self.tutor, self.feedback = \
            data_factories.make_minimal_exam()
        self.student = self.submission.student
        self.reviewer = Reviewer.objects.create(
            user=data_factories.make_user(username='reviewer'))
        self.request = self.factory.get(reverse('student-page'))
        self.view = StudentApiView.as_view()

        force_authenticate(self.request, user=self.student.user)
        self.response = self.view(self.request)

        self.exam_obj = self.response.data['exam']
        self.submission_list = self.response.data['submissions']
        self.submission_list_first_entry = self.submission_list[0]

    def test_student_information_contains_name(self):
        self.assertEqual(
            self.response.data['name'], self.student.user.fullname)

    def test_student_contains_associated_user(self):
        self.assertEqual(
            self.response.data['user'], self.student.user.username)

    def test_all_student_submissions_are_loded(self):
        self.assertEqual(len(self.submission_list),
                         SubmissionType.objects.count())

    # Tests concerning exam data
    def test_exam_data_contains_module_reference(self):
        self.assertEqual(
            self.exam_obj["module_reference"],
            self.student.exam.module_reference)

    def test_exam_data_contains_total_score(self):
        self.assertEqual(
            self.exam_obj["total_score"], self.student.exam.total_score)

    def test_exam_data_contains_pass_score(self):
        self.assertEqual(
            self.exam_obj["pass_score"], self.student.exam.pass_score)

    def test_exam_data_contains_pass_only_field(self):
        self.assertEqual(
            self.exam_obj["pass_only"], self.student.exam.pass_only)

    # Tests concerning submission data
    def test_a_student_submissions_contains_type(self):
        self.assertEqual(
            self.submission_list_first_entry['type'],
            self.student.submissions.first().type.name)

    def test_submission_data_contains_text(self):
        self.assertEqual(
            self.submission_list_first_entry['text'],
            self.student.submissions.first().text)

    def test_submission_data_contains_feedback(self):
        self.assertEqual(
            self.submission_list_first_entry['feedback'],
            self.student.submissions.first().feedback.text)

    def test_submission_data_contains_score(self):
        self.assertEqual(
            self.submission_list_first_entry['score'],
            self.student.submissions.first().feedback.score)

    def test_submission_data_contains_full_score(self):
        self.assertEqual(
            self.submission_list_first_entry['full_score'],
            self.student.submissions.first().type.full_score)

    # We don't want a matriculation number here
    def test_matriculation_number_is_not_senf(self):
        self.assertNotIn('matrikel_no', self.submission_list_first_entry)
