""" Two api endpoints are currently planned

    * GET /tutor/:id to retrive information about some tutor
    * POST /tutor/:username/:email create a new tutor and email password
    * GET /tutorlist list of all tutors with their scores
"""

from rest_framework.test import APITestCase, APIRequestFactory, force_authenticate
from rest_framework import status
from django.urls import reverse
from core.views import TutorListApiView
from core.models import Tutor

from util.factories import GradyUserFactory

NUMBER_OF_TUTORS = 7


class TutorAPIEndpoints(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.factory = APIRequestFactory()
        cls.user_factory = GradyUserFactory()

    def setUp(self):
        self.tutor_list = [self.user_factory.make_tutor()
                           for _ in range(NUMBER_OF_TUTORS)]
        self.reviewer = self.user_factory.make_reviewer()
        self.request = self.factory.get(reverse('tutorlist'))
        self.view = TutorListApiView.as_view()

        force_authenticate(self.request, user=self.reviewer.user)
        self.response = self.view(self.request)

    def test_can_access(self):
        self.assertEqual(self.response.status_code, status.HTTP_200_OK)

    def test_get_a_list_of_all_tutors(self):
        self.assertEqual(len(self.response.data), NUMBER_OF_TUTORS)

    def test_sum_of_feedback_count_matches_database(self):
        def verify_fields(tutor_obj):
            t = Tutor.objects.get(user__username=tutor_obj['username'])
            return t.get_feedback_count() == tutor_obj['feedback_count']

        self.assertTrue(all(map(verify_fields, self.response.data)))
