import logging

from rest_framework.generics import RetrieveAPIView, ListAPIView

from core.permissions import IsStudent, IsReviewer
from core.serializers import StudentSerializer, TutorSerializer
from core.models import Tutor

log = logging.getLogger(__name__)


class StudentApiView(RetrieveAPIView):
    permission_classes = (IsStudent,)

    def get_object(self):
        log.debug("Serializing student of user '%s'",
                  self.request.user.username)
        return self.request.user.student
    serializer_class = StudentSerializer


class TutorListApiView(ListAPIView):
    """ A list of all tutors with informationi about what they corrected """
    permission_classes = (IsReviewer,)
    queryset = Tutor.objects.all()
    serializer_class = TutorSerializer
